### Videos

There and back again: a packet's tale

{video url="https://www.youtube.com/embed/WwyJGzZmBe8"}

How does the internet work?

{video url="https://www.youtube.com/embed/i5oe63pOhLI"}

How the internet works in 5 minutes

{video url="https://www.youtube.com/embed/7_LPdttKXPc"}

